// src/csv.ts
import { downloadCsvFile, isArray, parseCsv, stringifyCsv } from "@csv-js/core";
var Csv = class {
  constructor(header, options) {
    this.data = [];
    this.info = {
      name: `csvjs-${+new Date()}`
    };
    this.header = header;
    if (options && options.name) {
      this.info.name = options.name;
    }
  }
  append(row) {
    const rows = isArray(row) ? row : [row];
    this.data.push(...rows);
  }
  prepend(row) {
    const rows = isArray(row) ? row : [row];
    this.data.unshift(...rows);
  }
  insert(index, row) {
    const rows = isArray(row) ? row : [row];
    this.data.splice(index, 0, ...rows);
  }
  remove(index) {
    this.data.splice(index, 1);
  }
  cover(index, row) {
    this.data[index] = row;
  }
  findIndexes(key, value) {
    const result = [];
    this.data.forEach((val, index) => {
      if (val[key] === value)
        result.push(index);
    });
    return result;
  }
  toString() {
    return stringifyCsv(
      this.data,
      this.header
    );
  }
  toHeaderKeys() {
    return this.header.map((v) => v.key);
  }
  download(name = "") {
    downloadCsvFile(
      name || this.info.name,
      this.toString()
    );
  }
  static import(csvString, headerKeys, options) {
    const { data, header } = parseCsv(csvString, headerKeys);
    const instance = new this(header, options);
    instance.append(data);
    return instance;
  }
};

// src/index.ts
var src_default = Csv;
export {
  src_default as default
};
